@@ -1,6 +1,7 @@
-import sys
+from typing import _GenericAlias  # type: ignore
+from typing import ClassVar
 
-from typing_extensions import TYPE_CHECKING, Protocol
+from typing_extensions import Protocol
 
 # Single-sourcing the version number with poetry:
 # https://github.com/python-poetry/poetry/pull/2366#issuecomment-652418094
@@ -74,20 +75,5 @@ def _is_a_protocol(t: type) -> bool:
     return Protocol in t.__bases__
 
 
-if TYPE_CHECKING:  # pragma: no cover
-
-    def _is_classvar(t: type) -> bool:
-        ...
-
-else:  # pragma: no cover
-    if sys.version_info < (3, 7):
-        from typing import _ClassVar
-
-        def _is_classvar(t: type) -> bool:
-            return type(t) is _ClassVar
-
-    else:
-        from typing import ClassVar, _GenericAlias
-
-        def _is_classvar(t: type) -> bool:
-            return type(t) is _GenericAlias and t.__origin__ is ClassVar
+def _is_classvar(t: type) -> bool:
+    return type(t) is _GenericAlias and t.__origin__ is ClassVar
